@@ -9,6 +9,13 @@ def build_cli():
     cli_runner.add_commands(READ_COMMANDS, namespace="Read")
     cli_runner.add_commands(WRITE_COMMANDS, namespace="Write")
     cli_runner.add_commands(hn_context.get_context_commands(), namespace="Cache")
+    cli_runner.add_aliases({
+        "fp": "get_front_page",
+        "fps": "get_front_page -t SHOW",
+        "fpa": "get_front_page -t ASK",
+        "gt": "get_tree",
+        "gu": "get_user -sn 10"
+    })
     return cli_runner
 
 
