@@ -1,6 +1,5 @@
 import os
 import re
-import sys
 import time
 import html
 import argparse
@@ -55,7 +54,6 @@ def send_reply_form(item_id, text, context, is_story=True):
         form_data["goto"] = sub_link
     send_comment_request(form_data, context.user_cookie)
     print("\033[0;32mComment Published\033[0m")
-    sys.stdout.flush()
     context.drop_item(item_id) # Parent will need to be reloaded
 
 
